@@ -15,7 +15,7 @@ def pyls_references(document, position, exclude_declaration=False):
         usages = [d for d in usages if not d.is_definition()]
 
     return [{
-        'uri': workspace.get_uri_like(document.uri, d.module_path),
+        'uri': workspace.get_uri_like(document.uri, d.module_path) if d.module_path else document.uri,
         'range': {
             'start': {'line': d.line - 1, 'character': d.column},
             'end': {'line': d.line - 1, 'character': d.column + len(d.name)}
