@@ -4,7 +4,7 @@ import logging
 import os
 import re
 import sys
-from urllib.parse import urlparse, urlunparse, unquote
+from urllib.parse import urlparse, urlunparse, quote, unquote
 
 import jedi
 
@@ -23,8 +23,8 @@ class Workspace(object):
     M_APPLY_EDIT = 'workspace/applyEdit'
     M_SHOW_MESSAGE = 'window/showMessage'
 
-    def __init__(self, root, lang_server=None):
-        self._url_parsed = urlparse(root)
+    def __init__(self, root_uri, lang_server=None):
+        self._url_parsed = urlparse(root_uri)
         self.root = unquote(self._url_parsed.path)
         self._docs = {}
         self._lang_server = lang_server
@@ -72,7 +72,7 @@ class Workspace(object):
         return path
 
     def is_in_workspace(self, path):
-        return os.path.commonprefix((self.root, path))
+        return not self.root or os.path.commonprefix((self.root, path))
 
 
 class Document(object):
@@ -181,5 +181,10 @@ def get_uri_like(doc_uri, path):
     unicode objects.
     """
     parts = list(urlparse(doc_uri))
+    if path[0] != '/' and ':' in path:  # fix path for windows
+        drivespec, path = path.split(':', 1)
+        path = '/' + drivespec + ':' + quote(path.replace('\\', '/'))
+    else:
+        path = quote(path)
     parts[2] = path
     return urlunparse([str(p) for p in parts])
